@@ -60,6 +60,10 @@ static const char USAGE_MESSAGE[] =
 "      --adj             output the graph in adj format\n"
 "      --dot             output the graph in dot format [default]\n"
 "      --dot-meancov     same as above but give the mean coverage\n"
+"      --gfa             output the graph in GFA1 format\n"
+"      --gfa1            output the graph in GFA1 format\n"
+"      --gfa2            output the graph in GFA2 format\n"
+"      --gv              output the graph in GraphViz format\n"
 "      --sam             output the graph in SAM format\n"
 "  -v, --verbose         display verbose output\n"
 "      --help            display this help and exit\n"
@@ -105,6 +109,10 @@ static const struct option longopts[] = {
 	{ "adj", no_argument, &opt::format, ADJ },
 	{ "dot", no_argument, &opt::format, DOT },
 	{ "dot-meancov", no_argument, &opt::format, DOT_MEANCOV },
+	{ "gfa", no_argument, &opt::format, GFA1 },
+	{ "gfa1", no_argument, &opt::format, GFA1 },
+	{ "gfa2", no_argument, &opt::format, GFA2 },
+	{ "gv", no_argument, &opt::format, DOT },
 	{ "sam", no_argument, &opt::format, SAM },
 	{ "graph", required_argument, NULL, 'g' },
 	{ "kmer",        required_argument, NULL, 'k' },
@@ -255,9 +263,10 @@ static void mergeContigs(const Graph& g, const Contigs& contigs,
 static void pathToComment(ostream& out,
 		const Graph& g, const ContigPath& path)
 {
-	assert(path.size() > 1);
 	out << get(vertex_name, g, path.front());
-	if (path.size() == 3)
+	if (path.size() == 1)
+		return;
+	else if (path.size() == 3)
 		out << ',' << get(vertex_name, g, path[1]);
 	else if (path.size() > 3)
 		out << ",...";
@@ -525,10 +534,12 @@ int main(int argc, char** argv)
 			if (!adjPath.empty()
 					&& g_contigNames.count(rec.id) == 0)
 				continue;
-			if (adjPath.empty())
-				put(g_contigNames, contigs.size(), rec.id);
-			else
-				assert(get(g_contigNames, rec.id) == contigs.size());
+			if (adjPath.empty()) {
+				graph_traits<Graph>::vertex_descriptor
+					u = add_vertex(ContigProperties(rec.seq.length(), 0), g);
+				put(vertex_name, g, u, rec.id);
+			}
+			assert(get(g_contigNames, rec.id) == contigs.size());
 			contigs.push_back(rec);
 
 			++count;
@@ -581,9 +592,6 @@ int main(int argc, char** argv)
 		}
 	}
 
-	if (adjPath.empty())
-		return 0;
-
 	unsigned npaths = 0;
 	for (ContigPaths::const_iterator it = paths.begin();
 			it != paths.end(); ++it) {
